@@ -1,7 +1,7 @@
 use super::*;
 use crate::api::media_engine::MIME_TYPE_OPUS;
 use crate::api::APIBuilder;
-use crate::peer::configuration::RTCConfiguration;
+use crate::peer_connection::configuration::RTCConfiguration;
 use regex::Regex;
 use std::io::Cursor;
 
